# Script to remove all netflow related data in the database. 
# This script is to be run after NetFlow Analyzer is shutdown.
# Use startDB.sh to start the database before running this script.
 
    initVar() {	
	fileName="tables.list"
	dbName="mickeylite"
	userName="root"
	password=""
	logfile="remove.log"	
	sock="../mysql/tmp/mysql.sock"
    mysql="../mysql/bin/mysql"
    sqlfile="createBaseTables.sql"
    metasqlfile="populateMetaTable.sql"
}

removeContents() 
{
	log "`date` Started removing contents based on list file $fileName"
	log ""
	echo "set FOREIGN_KEY_CHECKS = 0" | $mysql -S $sock  -u $userName $password $dbName
	dropTable DstIf1Min
	dropTable SrcIf1Min
	dropTable SrcIfPkt1Min
	dropTable DstIfPkt1Min
	for table in $tableList 
	do 
		dropTable $table
	done
# remove MetaTable also
	dropTable MetaTable
	dropTable RawMetaTable
	echo "set FOREIGN_KEY_CHECKS = 1" | $mysql -S $sock  -u $userName $password $dbName
	log ""
	log "`date` Removed contents"
}

dropTable()
{
		
		echo "drop table if exists $1 " | $mysql -S $sock  -u $userName $password $dbName >> ${logfile} 2>&1
		if [ $? -eq 0 ] 
		then
			log "Dropped $1"
			echo "Dropped $1"
		else
			log "Unable to drop $1"
			echo "Unable to drop $1"
		fi
	
}

log() {
	message="$1"
	echo "${message}" >> ${logfile} 2>&1
	#echo "${message}"
}

getTableList()
{
	touch $fileName
	touch temp.list
	touch temp1.list
	echo "select LOOKUP_TABLENAME from MetaTable"|$mysql -S $sock  -u $userName $password $dbName >> temp.list
	sed -e '1d' temp.list >> $fileName
	echo "select LOOKUP_TABLENAME from RawMetaTable"|$mysql -S $sock  -u $userName $password $dbName >> temp1.list
	sed -e '1d' temp1.list >> $fileName
	echo "delete from EventRecord"|$mysql -S $sock  -u $userName $password $dbName
	tableList=`cat $fileName`
	touch $logfile
}

checkServerStatus()
{
      JAVA_HOME=../jre
      NETFLOW_HOME=../conf/server.xml
      UTIL_CLASSPATH=../lib/NFACOL.jar
      JAVA=$JAVA_HOME/bin/java

      export JAVA_HOME
      export NETFLOW_HOME
      export UTIL_CLASSPATH
      export JAVA

      $JAVA "-Dcontext=netflow" -cp $UTIL_CLASSPATH com.adventnet.netflow.dbutils.NFClientUtil $NETFLOW_HOME 1
		 
		 if [ $? -ne 254 ]
		 then
		 info="Netflow server is running. Shutdown server before dropping data tables"
		 log $info
		 echo $info
		 exit 1
		 else
		 log  "Server not running. Beginning of drop tables" >> ${logfile} 2>&1
		 fi
}
removeLogFiles()
{
	for name in $fileName temp.list temp1.list $logfile
	do
	if [ -r $name ]
		then
		echo  "Deleting previous $name"
		rm -r $name
	fi
	done
}

createTables()
{
echo "Recreating tables"
$mysql -S $sock  -u $userName $password $dbName < $sqlfile
$mysql -S $sock  -u $userName $password $dbName < $metasqlfile

}

main() {
	initVar
	removeLogFiles
	checkServerStatus
	getTableList
	removeContents
    createTables
}

main * 
